@@ -8,7 +8,7 @@
 #   A Perl Module Chain to faciliate the Creation and Modification
 #   of High-Quality "Portable Document Format (PDF)" Files.
 #
-#   Copyright 1999-2004 Alfred Reibenschuh <areibens@cpan.org>.
+#   Copyright 1999-2005 Alfred Reibenschuh <areibens@cpan.org>.
 #
 #=======================================================================
 #
@@ -27,7 +27,7 @@
 #   Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 #   Boston, MA 02111-1307, USA.
 #
-#   $Id: Pattern.pm,v 1.3 2004/12/16 00:30:53 fredo Exp $
+#   $Id: Pattern.pm,v 1.4 2005/03/14 22:01:06 fredo Exp $
 #
 #=======================================================================
 
@@ -44,7 +44,7 @@ BEGIN {
 
     @ISA = qw(PDF::API2::Resource);
 
-    ( $VERSION ) = '$Revision: 1.3 $' =~ /Revision: (\S+)\s/; # $Date: 2004/12/16 00:30:53 $
+    ( $VERSION ) = '$Revision: 1.4 $' =~ /Revision: (\S+)\s/; # $Date: 2005/03/14 22:01:06 $
 
 }
 no warnings qw[ deprecated recursion uninitialized ];
@@ -103,6 +103,9 @@ alfred reibenschuh
 =head1 HISTORY
 
     $Log: Pattern.pm,v $
+    Revision 1.4  2005/03/14 22:01:06  fredo
+    upd 2005
+
     Revision 1.3  2004/12/16 00:30:53  fredo
     added no warn for recursion
 
